Crate microcad_lang_parse

Crate microcad_lang_parse 

Syntax definitions and parser for µcad source code.

This module includes the components to parse µcad source code into a stream of tokens or abstract syntax tree.

  • Transform source code into a stream of tokens with [lex]
  • Create an abstract syntax tree from the list of tokens with parse

Modules

ast
Abstract syntax tree for µcad files
parsers
Chumsky parser functions for µcad syntax elements
tokens
Source tokens for µcad files

Structs

ParseError
An error from building the abstract syntax tree
ParseErrors
Parse error collection.

Enums

ParseContext
Context for parsing.

Traits

Parse
Parse trait.

Functions

parse
API to parse directly from a string